@@ -1,4 +1,4 @@
-// $Id: inet.h,v 1.3 2002/06/12 00:42:51 ensc Exp $    --*- c++ -*--
+// $Id: inet.h,v 1.6 2002/07/10 09:40:13 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -16,25 +16,28 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //  
 
-#ifndef DHCP_FORWARDER_INET_H
-#define DHCP_FORWARDER_INET_H
+#ifndef DHCP_FORWARDER_SRC_INET_H
+#define DHCP_FORWARDER_SRC_INET_H 1
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include "splint.h"
 
-#include "splint_compat.h"
-
-#include <netinet/ether.h>
 #include <netinet/ip.h>
+#include <netinet/ether.h>
 #include <netinet/udp.h>
 
 #include "compat.h"
 
+  /*@-exportconst@*/
+  /*@constant uint16_t DHCP_PORT_CLIENT@*/
+  /*@constant uint16_t DHCP_PORT_SERVER@*/
+  /*@=exportconst@*/
+
+#ifndef S_SPLINT_S
 enum {
-  DHCP_PORT_SERVER = 67,
-  DHCP_PORT_CLIENT = 68
+  DHCP_PORT_SERVER = 67u,
+  DHCP_PORT_CLIENT = 68u
 };
+#endif // S_SPLINT_S
 
 struct DHCPllPacket
 {
@@ -44,7 +47,7 @@ struct DHCPllPacket
     __extension__ char		data __flexarr;
 } __attribute__((__packed__));
 
-#endif	/* DHCP_FORWARDER_INET_H */
+#endif	/* DHCP_FORWARDER_SRC_INET_H */
 
   // Local Variables:
   // compile-command: "make -C .. -k"
