@@ -1,4 +1,4 @@
-// $Id: logging.c,v 1.9 2002/07/11 22:40:51 ensc Exp $    --*- c++ -*--
+// $Id: logging.c,v 1.10 2002/08/29 13:25:06 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -135,8 +135,9 @@ logDHCPPackage(char const *data, size_t	len,
 
     (void)Xinet_ntop(saddr->sa_family, ptr, addr_buffer, sizeof addr_buffer);
 
-    buffer_ptr = buffer;
-    avail      = sizeof(buffer);
+    buffer_ptr    = buffer;
+    avail         = sizeof(buffer)-1;
+    buffer[avail] = '\0';
     
 #if 1
     Xsnprintf(&buffer_ptr, &avail, "from %s (", addr_buffer) ;
