@@ -1,4 +1,4 @@
-// $Id: wrappers.h,v 1.12 2002/07/12 11:52:54 ensc Exp $    --*- c++ -*--
+// $Id: wrappers.h,v 1.14 2002/08/29 13:28:47 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -27,7 +27,6 @@
 #include <pwd.h>
 #include <grp.h>
 #include <stdio.h>
-#include <alloca.h>
 #include <sys/resource.h>
 #include <grp.h>
 #include <fcntl.h>
@@ -86,6 +85,16 @@ Egetpwnam(char const *name)
   return res;
 }
 
+/*@unused@*/
+inline static pid_t
+Esetsid()
+{
+  pid_t		res = setsid();
+  FatalErrnoError(res==-1, 1, "setsid()");
+
+  return res;
+}
+
 /*@unused@*/
 inline static void
 Echroot(char const path[])
@@ -160,22 +169,6 @@ Emalloc(size_t size)
     /*@=compdef@*/
 }
 
-/*@unused@*/
-inline static /*@null@*//*@temp@*//*@only@*/ void *
-Ealloca(size_t size)
-    /*@ensures maxSet(result) == size@*/
-    /*@*/
-{
-    /*@-modunconnomods@*/
-  register void /*@temp@*/		*res = alloca(size);
-    /*@=modunconnomods@*/
-  
-  FatalErrnoError(res==0 && size!=0, 1, "malloc()");
-    /*@-freshtrans -mustfreefresh@*/
-  return res;
-    /*@=freshtrans =mustfreefresh@*/
-}
-
 /*@unused@*/
 inline static int
 Edup(int fd)
